@@ -32,8 +32,9 @@
 #include <QtGui/QMessageBox>
 #include <QtGui/QMenuBar>
 #include <QtGui/QCloseEvent>
-
+#include <QtGui/QVBoxLayout>
 #include <QtGui/QListView>
+#include <QtGui/QLabel>
 
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -96,8 +97,17 @@ void MainWindowPrivate::init()
   listWidget.setModel(model);
   listWidget.setSelectionMode(QAbstractItemView::NoSelection);
 
+  QWidget* welcomeScreen = new QWidget;
+  QLabel* label = new QLabel(tr("Please select a provider:"));
+
+  QVBoxLayout* layout = new QVBoxLayout;
+  layout->addWidget(label);
+  layout->addWidget(&listWidget);
+
+  welcomeScreen->setLayout(layout);
+
   // Set the message widget as central widget
-  self->setCentralWidget(&listWidget);
+  self->setCentralWidget(welcomeScreen);
 
   // Connect signals and slots
   connect(&listWidget, SIGNAL(clicked(QModelIndex)), this, SLOT(onClicked(QModelIndex)));
